/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2003 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.conf.module;

import java.security.Principal;
import java.util.*;
import com.silverwrist.dynamo.except.*;
import com.silverwrist.dynamo.iface.*;
import com.silverwrist.dynamo.util.*;
import com.silverwrist.venice.conf.ConfNamespaces;

public class ModuleMain implements ModuleFunctions
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  public static final String CONTROLLER_OBJNAME = "controller";

  private static final QualifiedNameKey NAME =
      new QualifiedNameKey(ConfNamespaces.CONFERENCING_NAMESPACE,"Venice.conferencing");

  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private int m_usecount = 0;
  private ModuleSite m_site = null;
  private Controller m_controller = null;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  public ModuleMain()
  { // do nothing
  } // end constructor

  /*--------------------------------------------------------------------------------
   * Implementations from interface ModuleFunctions
   *--------------------------------------------------------------------------------
   */

  public QualifiedNameKey getModuleID()
  {
    return NAME;

  } // end getModuleID

  public String getDescription()
  {
    ResourceBundle b = ResourceBundle.getBundle("com.silverwrist.venice.conf.module.ModuleMessages");
    return b.getString("description");

  } // end getDescription

  public void initialize(ModuleSite site, ServiceProvider services) throws ModuleException
  {
    m_site = site;

  } // end initialize

  public void shutdown()
  {
    m_site = null;
    m_controller = null;
    m_usecount = 0;

  } // end shutdown

  public boolean inUse()
  {
    return (m_usecount>0);

  } // end inUse

  public boolean canInstall(ServiceProvider services, Principal installer)
  {
    return true;  // TEMP
  }

  public void install(ModuleSite site, ServiceProvider services, Principal installer, DynamoLog log)
      throws ModuleException
  {
  }

  public void uninstall(ModuleSite site, ServiceProvider services, Principal uninstaller, DynamoLog log)
      throws ModuleException
  {
  }

  public DynamicObject getProvidedObject(String namespace, String name) throws ModuleException
  {
    if (ConfNamespaces.CONFERENCING_NAMESPACE.equals(namespace) && CONTROLLER_OBJNAME.equals(name))
    { // we want the community service controller
      synchronized (this)
      { // create it if necessary
	if (m_controller==null)
	  m_controller = new Controller();
	return m_controller;

      } // end synchronized block

    } // end if

    return null;

  } // end getProvidedObject

} // end class ModuleMain
